@@ -1,13 +1,17 @@
 import django
+import json
+import os
 
 from datetime import datetime, timedelta
 
-from django.conf import settings as django_settings
+from django.conf import settings as django_settings, settings
 from django.core import mail
+from django.core import serializers
 from django.core.files.base import ContentFile
 from django.core.mail import EmailMessage, EmailMultiAlternatives
 from django.forms.models import modelform_factory
 from django.test import TestCase
+from django.utils import timezone
 
 from ..models import Email, Log, PRIORITY, STATUS, EmailTemplate, Attachment
 from ..mail import send
@@ -70,6 +74,15 @@ class ModelTest(TestCase):
         email.dispatch()
         self.assertEqual(mail.outbox[0].subject, 'Test dispatch')
 
+    def test_dispatch_with_override_recipients(self):
+        previous_settings = settings.POST_OFFICE
+        setattr(settings, 'POST_OFFICE', {'OVERRIDE_RECIPIENTS': ['override@gmail.com']})
+        email = Email.objects.create(to=['to@example.com'], from_email='from@example.com',
+                                     subject='Test dispatch', message='Message', backend_alias='locmem')
+        email.dispatch()
+        self.assertEqual(mail.outbox[0].to, ['override@gmail.com'])
+        settings.POST_OFFICE = previous_settings
+
     def test_status_and_log(self):
         """
         Ensure that status and log are set properly on successful sending
@@ -210,13 +223,13 @@ class ModelTest(TestCase):
 
         self.assertFalse(form.is_valid())
 
-        self.assertEqual(form.errors['default_template'],  [u'This field is required.'])
-        self.assertEqual(form.errors['content'], [u"Invalid filter: 'titl'"])
+        self.assertEqual(form.errors['default_template'],  ['This field is required.'])
+        self.assertEqual(form.errors['content'], ["Invalid filter: 'titl'"])
         self.assertIn(form.errors['html_content'],
-                      [[u'Unclosed tags: endblock '],
-                       [u"Unclosed tag on line 1: 'block'. Looking for one of: endblock."]])
+                      [['Unclosed tags: endblock '],
+                       ["Unclosed tag on line 1: 'block'. Looking for one of: endblock."]])
         self.assertIn(form.errors['subject'],
-                      [[u'Empty variable tag'], [u'Empty variable tag on line 1']])
+                      [['Empty variable tag'], ['Empty variable tag on line 1']])
 
     def test_string_priority(self):
         """
@@ -259,6 +272,12 @@ class ModelTest(TestCase):
         )
         self.assertEqual(attachment.name, 'test.txt')
 
+        # Test that it is saved to the correct subdirectory
+        date = timezone.now().date()
+        expected_path = os.path.join('post_office_attachments', str(date.year),
+                                     str(date.month), str(date.day))
+        self.assertTrue(expected_path in attachment.file.name)
+
     def test_attachments_email_message(self):
         email = Email.objects.create(to=['to@example.com'],
                                      from_email='from@example.com',
@@ -271,13 +290,8 @@ class ModelTest(TestCase):
         email.attachments.add(attachment)
         message = email.email_message()
 
-        # https://docs.djangoproject.com/en/1.11/releases/1.11/#email
-        if django.VERSION >= (1, 11,):
-            self.assertEqual(message.attachments,
-                             [('test.txt', 'test file content', 'text/plain')])
-        else:
-            self.assertEqual(message.attachments,
-                             [('test.txt', b'test file content', None)])
+        self.assertEqual(message.attachments,
+                         [('test.txt', 'test file content', 'text/plain')])
 
     def test_attachments_email_message_with_mimetype(self):
         email = Email.objects.create(to=['to@example.com'],
@@ -293,12 +307,8 @@ class ModelTest(TestCase):
         email.attachments.add(attachment)
         message = email.email_message()
 
-        if django.VERSION >= (1, 11,):
-            self.assertEqual(message.attachments,
-                             [('test.txt', 'test file content', 'text/plain')])
-        else:
-            self.assertEqual(message.attachments,
-                             [('test.txt', b'test file content', 'text/plain')])
+        self.assertEqual(message.attachments,
+                         [('test.txt', 'test file content', 'text/plain')])
 
     def test_translated_template_uses_default_templates_name(self):
         template = EmailTemplate.objects.create(name='name')
@@ -310,3 +320,13 @@ class ModelTest(TestCase):
                          '<EmailTemplate: test en>')
         self.assertEqual(repr(Email(to=['test@example.com'])),
                          "<Email: ['test@example.com']>")
+
+    def test_natural_key(self):
+        template = EmailTemplate.objects.create(name='name')
+        self.assertEqual(template, EmailTemplate.objects.get_by_natural_key(*template.natural_key()))
+
+        data = serializers.serialize('json', [template], use_natural_primary_keys=True)
+        self.assertNotIn('pk', json.loads(data)[0])
+        deserialized_objects = serializers.deserialize('json', data, use_natural_primary_keys=True)
+        list(deserialized_objects)[0].save()
+        self.assertEqual(EmailTemplate.objects.count(), 1)
