@@ -41,6 +41,7 @@ class UtilsTest(TestCase):
         # These should raise ValidationError
         self.assertRaises(ValidationError, validate_email_with_name, 'invalid')
         self.assertRaises(ValidationError, validate_email_with_name, 'Al <ab>')
+        self.assertRaises(ValidationError, validate_email_with_name, 'Al <>')
 
     def test_comma_separated_email_list_validator(self):
         # These should validate
@@ -143,6 +144,26 @@ class UtilsTest(TestCase):
         self.assertTrue(attachments[0].pk)
         self.assertEqual(attachments[0].file.read(), b'content')
         self.assertTrue(attachments[0].name.startswith('attachment_file'))
+        self.assertEquals(attachments[0].mimetype, '')
+
+    def test_create_attachments_with_mimetype(self):
+        attachments = create_attachments({
+            'attachment_file1.txt': {
+                'file': ContentFile('content'),
+                'mimetype': 'text/plain'
+            },
+            'attachment_file2.jpg': {
+                'file': ContentFile('content'),
+                'mimetype': 'text/plain'
+            }
+        })
+
+        self.assertEqual(len(attachments), 2)
+        self.assertIsInstance(attachments[0], Attachment)
+        self.assertTrue(attachments[0].pk)
+        self.assertEquals(attachments[0].file.read(), b'content')
+        self.assertTrue(attachments[0].name.startswith('attachment_file'))
+        self.assertEquals(attachments[0].mimetype, 'text/plain')
 
     def test_create_attachments_open_file(self):
         attachments = create_attachments({
@@ -153,7 +174,8 @@ class UtilsTest(TestCase):
         self.assertIsInstance(attachments[0], Attachment)
         self.assertTrue(attachments[0].pk)
         self.assertTrue(attachments[0].file.read())
-        self.assertEqual(attachments[0].name, 'attachment_file.py')
+        self.assertEquals(attachments[0].name, 'attachment_file.py')
+        self.assertEquals(attachments[0].mimetype, '')
 
     def test_parse_priority(self):
         self.assertEqual(parse_priority('now'), PRIORITY.now)
